@@ -3,18 +3,46 @@ package POE::Loop::EV;
 # EV.pm (libev) event loop bridge
 # $Id: EV.pm 27 2008-01-29 19:42:57Z andyg $
 
+use warnings;
 use strict;
 use POE::Loop::PerlSignals;
+use EV;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
+
+my %methods;
+sub _backend_name {
+    return undef unless defined( my $backend = shift );
+    %methods = (
+        EV::BACKEND_SELECT()  => 'select',
+        EV::BACKEND_POLL()    => 'poll',
+        EV::BACKEND_EPOLL()   => 'epoll',
+        EV::BACKEND_KQUEUE()  => 'kqueue',
+        EV::BACKEND_DEVPOLL() => 'devpoll',
+        EV::BACKEND_PORT()    => 'port',
+    ) unless keys %methods;
+    return $methods{ $backend };
+}
 
 =for poe_tests
+use EV;
+BEGIN { $ENV{POE_EVENT_LOOP} = 'POE::Loop::EV'; $ENV{POE_LOOP_USES_POLL} = 1 if EV::backend() == EV::BACKEND_POLL(); }
 sub skip_tests {
-    return "EV tests require the EV module" if (
-        do { eval "use EV"; $@ }
-    );
-    return "wheel_readwrite test disabled for kqueue"
+    return "wheel_readwrite test disabled for 'kqueue'"
         if EV::backend() == EV::BACKEND_KQUEUE() && $_[0] eq 'wheel_readwrite';
+    if ($_[0] eq '00_info') {
+        my %methods = ( # duplicated for generated tests
+            EV::BACKEND_SELECT()  => 'select',
+            EV::BACKEND_POLL()    => 'poll',
+            EV::BACKEND_EPOLL()   => 'epoll',
+            EV::BACKEND_KQUEUE()  => 'kqueue',
+            EV::BACKEND_DEVPOLL() => 'devpoll',
+            EV::BACKEND_PORT()    => 'port',
+        );
+        my $method = $methods{ EV::backend() };
+        diag("Using default EV backend '$method'");
+    }
+    return undef;
 }
 
 =cut
@@ -23,8 +51,6 @@ sub skip_tests {
 package # hide me from PAUSE
     POE::Kernel;
 
-use EV;
-
 # Loop debugging
 sub EV_DEBUG () { $ENV{POE_EV_DEBUG} || 0 }
 
@@ -46,16 +72,8 @@ sub loop_initialize {
     my $self = shift;
     
     if ( EV_DEBUG ) {
-        my $methods = {
-            EV::BACKEND_SELECT()  => 'select',
-            EV::BACKEND_POLL()    => 'poll',
-            EV::BACKEND_EPOLL()   => 'epoll',
-            EV::BACKEND_KQUEUE()  => 'kqueue',
-            EV::BACKEND_DEVPOLL() => 'devpoll',
-            EV::BACKEND_PORT()    => 'port',
-        };
-        
-        warn "loop_initialize, EV is using method: " . $methods->{ EV::backend() } . "\n";
+        my $method = POE::Loop::EV::_backend_name( EV::backend() );
+        warn "loop_initialize, EV is using method: $method\n";
     }
 
     # Set up the global timer object
@@ -269,8 +287,7 @@ POE::Loop::EV - a bridge that supports EV from POE
 
 =head1 SYNOPSIS
 
-    use EV;
-    use POE;
+    use POE 'Loop::EV';
     
     ...
     
@@ -313,9 +330,11 @@ Dan Book <dbook@cpan.org>
 
 Brandon Black, for his L<POE::Loop::Event_Lib> module.
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-POE::Loop::EV is free software; you may redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2007 by Andy Grundman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
